#
# spec file for package copacetic
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name copa
Name:           copacetic
Version:        0.10.0
Release:        1.1
Summary:        CLI tool for directly patching container images using reports from vulnerability scanners
License:        Apache-2.0
URL:            https://github.com/project-copacetic/copacetic
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.23.5

%description
copa is a CLI tool written in Go and based on buildkit that can be used to
directly patch container images given the vulnerability scanning results from
popular tools like Trivy.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %{_sourcedir}/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/project-copacetic/copacetic/pkg/version.GitCommit=${COMMIT_HASH} \
   -X github.com/project-copacetic/copacetic/pkg/version.GitVersion=%{version} \
   -X github.com/project-copacetic/copacetic/pkg/version.BuildDate=${BUILD_DATE} \
   -X main.version=%{version}" \
   -o bin/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{executable_name}

%changelog
* Fri Mar 14 2025 dcermak@suse.com
- update to version 0.10.0:
  https://github.com/project-copacetic/copacetic/releases/tag/v0.10.0
  * Notable changes
  - Copa now supports patching Alma Linux Images!
  - chore: update golangci-lint version (#930), fixes
    CVE-2025-22869 / bsc#1239421
- update to version 0.9.0:
  https://github.com/project-copacetic/copacetic/releases/tag/v0.9.0
  * Notable changes
  - Copa now supports patching Azure Linux 3 based images!
- update to version 0.8.0:
  https://github.com/project-copacetic/copacetic/releases/tag/v0.8.0
  * Notable changes
  - Copa now creates a single patch layer on subsequent patches
    of an already patched image instead of appending a patch
    layer for each patch! See FAQ for more information.
  - Oracle Linux is now supported for updating without
    vulnerability scanner reports. This will update all
    dependencies, including vulnerable packages. See
    documentation for more information.
- update to version 0.7.0:
  https://github.com/project-copacetic/copacetic/releases/tag/v0.7.0
  * Notable changes
  - Support for upgrading all outdated packages without a scanner
    report. See quick start to get started!
* Thu May 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package copacetic: CLI tool for directly patching container
  images using reports from vulnerability scanners
